/* storePiece.h
 */
#ifndef _STORE_PIECE_VECTOR_H
#define _STORE_PIECE_VECTOR_H
#include "osl/container/pieceVector.h"
namespace osl
{
  namespace effect_action
  {
    /**
     * PieceVector に格納
     */
    struct StorePiece
    {
      PieceVector *store;
      explicit StorePiece(PieceVector *s) : store(s)
      {
      }
      template<Player P,Ptype Type>
      void doActionPtype(Piece p, Square pos)
      {
	doAction<P>(p, pos);
      }
      template<Player P>
      void doAction(Piece p, Square)
      {
	store->push_back(p);
      }
    };
  } // namespace effect_action
} // namespace osl
#endif // _STORE_PIECE_VECTOR_H
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
